==> moserial-2.26.3.tar.bz2: moserial-2.26.3/src/RecordDialog.h <==

#ifndef __SRC_RECORDDIALOG_H__
#define __SRC_RECORDDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include "src/SerialStreamRecorder.h"

G_BEGIN_DECLS


#define MOSERIAL_TYPE_RECORD_DIALOG (moserial_record_dialog_get_type ())
#define MOSERIAL_RECORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialog))
#define MOSERIAL_RECORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialogClass))
#define MOSERIAL_IS_RECORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_RECORD_DIALOG))
#define MOSERIAL_IS_RECORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_RECORD_DIALOG))
#define MOSERIAL_RECORD_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialogClass))

typedef struct _moserialRecordDialog moserialRecordDialog;
typedef struct _moserialRecordDialogClass moserialRecordDialogClass;
typedef struct _moserialRecordDialogPrivate moserialRecordDialogPrivate;

struct _moserialRecordDialog {
	GObject parent_instance;
	moserialRecordDialogPrivate * priv;
	moserialSerialStreamRecorderDirection direction;
};

struct _moserialRecordDialogClass {
	GObjectClass parent_class;
};


moserialRecordDialog* moserial_record_dialog_construct (GType object_type, GtkBuilder* builder);
moserialRecordDialog* moserial_record_dialog_new (GtkBuilder* builder);
void moserial_record_dialog_show (moserialRecordDialog* self, const char* folder);
gboolean moserial_record_dialog_hide (moserialRecordDialog* self, GtkWidget* w);
GtkBuilder* moserial_record_dialog_get_builder (moserialRecordDialog* self);
const char* moserial_record_dialog_get_fileName (moserialRecordDialog* self);
GType moserial_record_dialog_get_type (void);


G_END_DECLS

#endif

==> moserial-2.27.5.tar.bz2: moserial-2.27.5/src/RecordDialog.h <==

#ifndef __SRC_RECORDDIALOG_H__
#define __SRC_RECORDDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include "src/SerialStreamRecorder.h"

G_BEGIN_DECLS


#define MOSERIAL_TYPE_RECORD_DIALOG (moserial_record_dialog_get_type ())
#define MOSERIAL_RECORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialog))
#define MOSERIAL_RECORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialogClass))
#define MOSERIAL_IS_RECORD_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_RECORD_DIALOG))
#define MOSERIAL_IS_RECORD_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_RECORD_DIALOG))
#define MOSERIAL_RECORD_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_RECORD_DIALOG, moserialRecordDialogClass))

typedef struct _moserialRecordDialog moserialRecordDialog;
typedef struct _moserialRecordDialogClass moserialRecordDialogClass;
typedef struct _moserialRecordDialogPrivate moserialRecordDialogPrivate;

struct _moserialRecordDialog {
	GObject parent_instance;
	moserialRecordDialogPrivate * priv;
	moserialSerialStreamRecorderDirection direction;
};

struct _moserialRecordDialogClass {
	GObjectClass parent_class;
};


moserialRecordDialog* moserial_record_dialog_construct (GType object_type, GtkBuilder* builder);
moserialRecordDialog* moserial_record_dialog_new (GtkBuilder* builder);
void moserial_record_dialog_show (moserialRecordDialog* self, const char* folder);
gboolean moserial_record_dialog_hide (moserialRecordDialog* self);
GtkBuilder* moserial_record_dialog_get_builder (moserialRecordDialog* self);
const char* moserial_record_dialog_get_fileName (moserialRecordDialog* self);
GType moserial_record_dialog_get_type (void);


G_END_DECLS

#endif
